# Turn off the brp-java-repack-jars script
%global __os_install_post %(echo '%{__os_install_post}' | sed -e 's!/usr/lib[^[:space:]]*/brp-java-repack-jars[[:space:]].*$!!g')

Name: argus-pdp

Version: 1.6.1
Release: 1%{?dist}
Summary: Argus PDP

Group: System Environment/Daemons
License: ASL 2.0
URL: https://twiki.cern.ch/twiki/bin/view/EGEE/AuthorizationFramework

Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch: noarch

BuildRequires: java-devel
BuildRequires: jpackage-utils
BuildRequires: maven

Requires: java
Requires: jpackage-utils
Requires: redhat-lsb
Requires: argus-pdp-pep-common >= 1.4

%description 
Argus PDP (Policy Decision Point).
The Argus Authorization Service renders consistent authorization 
decisions for distributed services (e.g., user interfaces, 
portals, computing elements, storage elements). The service is 
based on the XACML standard, and uses authorization policies to 
determine if a user is allowed or denied to perform a certain 
action on a particular service.
The Argus Authorization Service is composed of three main 
components:
- The Policy Administration Point (PAP) provides the tools to 
author authorization policies, organize them in the local 
repository and configure policy distribution among remote PAPs.
- The Policy Decision Point (PDP) implements the authorization 
engine, and is responsible for the evaluation of the authorization
requests against the XACML policies retrieved from the PAP.
- The Policy Enforcement Point Server (PEP Server) ensures the 
integrity and consistency of the authorization requests received 
from the PEP clients. Lightweight PEP client libraries are also 
provided to ease the integration and interoperability with other 
EMI services or components. 

%prep
%setup -q

%build
export JAVA_HOME=/usr/lib/jvm/java
make package

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

%clean
rm -rf $RPM_BUILD_ROOT

%pre
# on install (1): nothing
# on upgrade (2): stop the service, and clean up the lib directory
if [ $1 -eq 2 ] ; then
    /sbin/service argus-pdp stop > /dev/null 2>&1 || :
    # delete old jar 
    find /var/lib/argus/pdp/lib -name "*.jar" -exec rm {} \;
fi

%post
# on install (1): register the service in init.d
# on upgrade (2): nothing
if [ $1 -eq 1 ]; then 
    /sbin/chkconfig --add argus-pdp
fi
# correct files/dirs permission
chmod -f 640 %{_sysconfdir}/argus/pdp/pdp.ini
chmod -f 750 %{_datadir}/argus/pdp/sbin/pdpctl
chmod -f 750 %{_localstatedir}/log/argus/pdp

%preun
# on uninstall (0): stop and deregister the service
# on upgrade (1): nothing
if [ $1 -eq 0 ] ; then
    /sbin/service argus-pdp stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del argus-pdp
fi

%postun
# on uninstall (0): nothing
# on upgrade (1): restart the service 
if [ $1 -eq 1 ] ; then
    /sbin/service argus-pdp start
fi

%files
%defattr(-,root,root,-)
%{_sysconfdir}/init.d/argus-pdp
%dir %{_sysconfdir}/argus/pdp
%config(noreplace) %{_sysconfdir}/argus/pdp/logging.xml
%config(noreplace) %{_sysconfdir}/argus/pdp/pdp.ini
%config(noreplace) %{_sysconfdir}/sysconfig/argus-pdp
%{_sbindir}/pdpctl
%dir %{_datadir}/argus/pdp
%dir %{_datadir}/argus/pdp/sbin
%{_datadir}/argus/pdp/logs
%{_datadir}/argus/pdp/conf
%{_datadir}/argus/pdp/doc
%{_datadir}/argus/pdp/lib
%{_datadir}/argus/pdp/sbin/pdpctl
%dir %{_defaultdocdir}/argus/pdp
%{_defaultdocdir}/argus/pdp/COPYRIGHT
%{_defaultdocdir}/argus/pdp/LICENSE
%{_defaultdocdir}/argus/pdp/RELEASE-NOTES
%dir %{_localstatedir}/lib/argus/pdp/lib
%{_localstatedir}/lib/argus/pdp/lib/argus-pdp-1.6.1.jar
%{_localstatedir}/lib/argus/pdp/lib/commons-codec-*.jar
%{_localstatedir}/lib/argus/pdp/lib/commons-collections-*.jar
%{_localstatedir}/lib/argus/pdp/lib/commons-httpclient-*.jar
%{_localstatedir}/lib/argus/pdp/lib/commons-lang-*.jar
%{_localstatedir}/lib/argus/pdp/lib/commons-io-*.jar
%{_localstatedir}/lib/argus/pdp/lib/herasaf-xacml-core-*.jar
%{_localstatedir}/lib/argus/pdp/lib/ini4j-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jcl-over-slf4j-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jetty-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jetty-java5-threadpool-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jetty-sslengine-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jetty-util-*.jar
%{_localstatedir}/lib/argus/pdp/lib/joda-time-*.jar
%{_localstatedir}/lib/argus/pdp/lib/jul-to-slf4j-*.jar
%{_localstatedir}/lib/argus/pdp/lib/log4j-over-slf4j-*.jar
%{_localstatedir}/lib/argus/pdp/lib/logback-classic-*.jar
%{_localstatedir}/lib/argus/pdp/lib/logback-core-*.jar
%{_localstatedir}/lib/argus/pdp/lib/not-yet-commons-ssl-*.jar
%{_localstatedir}/lib/argus/pdp/lib/opensaml-*.jar
%{_localstatedir}/lib/argus/pdp/lib/openws-*.jar
%{_localstatedir}/lib/argus/pdp/lib/servlet-api-*.jar
%{_localstatedir}/lib/argus/pdp/lib/slf4j-api-*.jar
%{_localstatedir}/lib/argus/pdp/lib/velocity-*.jar
%{_localstatedir}/lib/argus/pdp/lib/xmlsec-*.jar
%{_localstatedir}/lib/argus/pdp/lib/xmltooling-*.jar
%dir %{_localstatedir}/lib/argus/pdp/lib/endorsed
%{_localstatedir}/lib/argus/pdp/lib/endorsed/serializer-*.jar
%{_localstatedir}/lib/argus/pdp/lib/endorsed/xalan-*.jar
%{_localstatedir}/lib/argus/pdp/lib/endorsed/xercesImpl-*.jar
%{_localstatedir}/lib/argus/pdp/lib/endorsed/xml-apis-*.jar
%{_localstatedir}/lib/argus/pdp/lib/endorsed/xml-resolver-*.jar
%dir %{_localstatedir}/lib/argus/pdp/lib/provided
%{_localstatedir}/lib/argus/pdp/lib/provided/bcprov-*.jar
%{_localstatedir}/lib/argus/pdp/lib/provided/canl-*.jar
%dir %{_localstatedir}/log/argus/pdp

%changelog
* Thu Oct  2 2014 Mischa Salle <msalle@nikhef.nl> 1.6.1-1
- Replace exact versions, except argus-pdp, in filelist with wildcard.
- Upstream version 1.6.1 for EMI-3.

* Thu Nov 18 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.6.0-1 
- Upstream version 1.6.0 for EMI-3.

* Mon Jul 30 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.5.2-1
- Self managed packaging with spec file.

* Tue Apr 3 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.5.1-1
- Initial Argus PDP for EMI 2.

